## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Container which contains the (student) accommodation objects.
"""
import grok
from grok import index
from zope.component.interfaces import IFactory
from waeup.sirp.students.interfaces import (
    IStudentAccommodation, IStudentNavigation, IBedTicket)
from waeup.sirp.utils.helpers import attrs_to_fields

class StudentAccommodation(grok.Container):
    """This is a container for accommodation objects.
    """
    grok.implements(IStudentAccommodation, IStudentNavigation)
    grok.provides(IStudentAccommodation)

    def __init__(self):
        super(StudentAccommodation, self).__init__()
        return

    def addBedTicket(self, bedticket):
        """Add a bed ticket object.
        """
        if not IBedTicket.providedBy(bedticket):
            raise TypeError(
                'StudentAccommodation containers contain only IBedTicket instances')
        self[bedticket.ticket_id] = bedticket
        return

    def getStudent(self):
        return self.__parent__

StudentAccommodation = attrs_to_fields(StudentAccommodation)

class BedTicket(grok.Model):
    """This is a bed ticket which shows that the student has booked a bed
    and paid the maintenance fee.
    """
    grok.implements(IBedTicket, IStudentNavigation)
    grok.provides(IBedTicket)

    def __init__(self):
        super(BedTicket, self).__init__()
        return

    def getStudent(self):
        return self.__parent__.__parent__

BedTicket = attrs_to_fields(BedTicket)